.. include:: ../BADGES.rst
Applications
============
check_equinox: Check the accuracy of the
equinox approximation routines over 4000 years.

cronus: A clock application that
displays a variety of celestial events in the order they
occur.

equinox-cgi:
A demo CGI interface to the Easter routine.

solstice: Displays the instants of
equinoxes and solstices for a range of years. Times are
accurate to one second.

solstice-cgi:
A demo CGI interface to the Solstice and Equinox
routines.
